@@ -1,7 +1,6 @@
 import unittest
 import os
 
-from pyramid_debugtoolbar.compat import bytes_
 from pyramid_debugtoolbar.compat import text_
 
 
@@ -33,7 +32,8 @@ class Test_format_fname(unittest.TestCase):
 
     def test_unknown(self):
         val = '..' + os.path.sep + 'foo'
-        self.assertEqual(self._callFUT(val), './../foo'.replace('/', os.path.sep))
+        self.assertEqual(self._callFUT(val),
+                         './../foo'.replace('/', os.path.sep))
 
     def test_module_file_path(self):
         sys_path = [
@@ -44,9 +44,11 @@ class Test_format_fname(unittest.TestCase):
 
         sys_path = map(lambda path: path.replace('/', os.path.sep), sys_path)
         modpath = self._callFUT(
-            '/foo/bar/pyramid_debugtoolbar/tests/debugfoo.py'.replace('/', os.path.sep), sys_path)
+            '/foo/bar/pyramid_debugtoolbar/tests/debugfoo.py'.replace(
+                '/', os.path.sep), sys_path)
         self.assertEqual(modpath, 
-            '<pyramid_debugtoolbar/tests/debugfoo.py>'.replace('/', os.path.sep))
+            '<pyramid_debugtoolbar/tests/debugfoo.py>'.replace(
+                             '/', os.path.sep))
 
     def test_no_matching_sys_path(self):
         val = '/foo/bar/pyramid_debugtoolbar/foo.py'
@@ -62,4 +64,25 @@ class Test_format_sql(unittest.TestCase):
 
     def test_it(self):
         result = self._callFUT('SELECT * FROM TBL')
-        self.assertTrue(result.startswith('<div'))
\ No newline at end of file
+        self.assertTrue(result.startswith('<div'))
+
+class Test_addr_in(unittest.TestCase):
+    def _callFUT(self, addr, hosts):
+        from pyramid_debugtoolbar.utils import addr_in
+        return addr_in(addr, hosts)
+
+    def test_empty_hosts(self):
+        self.assertFalse(self._callFUT('127.0.0.1', []))
+        
+
+    def test_not_in(self):
+        self.assertFalse(self._callFUT('127.0.0.1', ['192.168.1.1']))
+
+    def test_in(self):
+        self.assertTrue(self._callFUT('127.0.0.1', ['127.0.0.1']))
+
+    def test_in_multi(self):
+        self.assertTrue(self._callFUT('127.0.0.1', ['10.1.1.1', '127.0.0.1']))
+
+    def test_in_network(self):
+        self.assertTrue(self._callFUT('127.0.0.1', ['127.0.0.1/24']))
